Classes
=======

Additionally, there exists a F64 version for every class which is otherwise identical to the F32 version.

.. currentmodule:: pysplashsurf

.. autoclass:: Aabb3dF32

.. autoclass:: MixedTriQuadMesh3dF32

.. autoclass:: MixedTriQuadMeshWithDataF32
    :exclude-members: push_point_attribute_scalar_u64, push_point_attribute_scalar_real, push_point_attribute_vector_real, push_cell_attribute_scalar_real, push_cell_attribute_scalar_u64, push_cell_attribute_vector_real

.. autoclass:: SphInterpolatorF32

.. autoclass:: SurfaceReconstructionF32

.. autoclass:: TriMesh3dF32

.. autoclass:: TriMeshWithDataF32
    :exclude-members: push_point_attribute_scalar_u64, push_point_attribute_scalar_real, push_point_attribute_vector_real, push_cell_attribute_scalar_real, push_cell_attribute_scalar_u64, push_cell_attribute_vector_real

.. autoclass:: UniformGridF32